@@ -1,6 +1,6 @@
 from .deep_classifier import DeepClassifier
-from .text_rnn import TextRNNClassifier
-from .text_rcnn import TextRCNNClassifier
+from .rnn_classifier import TextRNNClassifier
+from .rcnn_classifier import TextRCNNClassifier
 from .bert_classifier import BertClassifier
 
 
