@@ -17,6 +17,7 @@ class BertTagger(DeepTagger):
         self,
         classes: Sequence[str],
         output_format: str = "global_pointer",
+        global_pointer_head_size: int = 64,
         crf_learning_rate_multiplier: float = 1.0,
         max_sequence_length: int = 120,
         num_fc_layers: int = 2,
@@ -30,6 +31,7 @@ class BertTagger(DeepTagger):
             classes,
             add_start_end_tag=True,
             output_format=output_format,
+            global_pointer_head_size=global_pointer_head_size,
             crf_learning_rate_multiplier=crf_learning_rate_multiplier,
             algorithm="bert",
             num_fc_layers=num_fc_layers,
